@@ -50,7 +50,6 @@ use cassandra_sys::cass_session_connect;
 use cassandra_sys::cass_session_new;
 use cassandra_sys::cass_true;
 
-// use ip::IpAddr;
 use std::ffi::{CString, CStr};
 use std::ffi::NulError;
 use std::fmt;
@@ -81,6 +80,10 @@ pub type CqlProtocol = i32;
 #[derive(Debug)]
 pub struct Cluster(pub *mut _Cluster);
 
+// The underlying C type has no thread-local state, but does not support access
+// from multiple threads: https://datastax.github.io/cpp-driver/topics/#thread-safety
+unsafe impl Send for Cluster {}
+
 impl Drop for Cluster {
     /// Frees a cluster instance.
     fn drop(&mut self) { unsafe { cass_cluster_free(self.0) } }
